package
Version:
v0.0.0-...-1d9206b
Opens a new window with list of versions in this module.
Published: Mar 25, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
type Version struct {
Major int
Minor int
Build int
Revision int
}
Version represents a Microsoft SQL Server version (e.g., "15.0.2095.3", "16.0.4165.4")
NewVersion returns a parsed version
Compare returns an integer comparing two versions.
The result will be 0 if v1==v2, -1 if v1 < v2, and +1 if v1 > v2.
String returns the version string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.